package cz.cvut.kbss.reporting.persistence.dao;

import cz.cvut.kbss.reporting.model.Person;
import org.springframework.stereotype.Repository;

import javax.persistence.NoResultException;
import java.util.List;

@Repository
public class PersonDao extends BaseDao<Person> {

    public PersonDao() {
        super(Person.class);
    }

    /**
     * Finds a {@link Person} instance with the specified username.
     *
     * @param username Username to filter by
     * @return Matching instance, {@code null} if none matches
     */
    public Person findByUsername(String username) {
        try {
            return em.createNamedQuery("Person.findByUsername", Person.class).setParameter("username", username)
                     .getSingleResult();
        } catch (NoResultException e) {
            return null;
        }
    }

    /**
     * Checks whether an instance with the specified username exists.
     *
     * @param username The username to search for
     * @return Record existence status
     */
    public boolean exists(String username) {
        final List result = em.createNativeQuery("SELECT 1 FROM person WHERE username=?")
                              .setParameter(1, username).getResultList();
        return !result.isEmpty();
    }
}
