'use strict';

import React from "react";
import PropTypes from "prop-types";
import assign from "object-assign";
import DateTimePicker from "react-bootstrap-datetimepicker";

import Events from "./Events";
import I18nWrapper from "../../../i18n/I18nWrapper";
import injectIntl from "../../../utils/injectIntl";
import Input from "../../Input";
import OccurrenceSeverity from "./OccurrenceSeverity";
import OccurrenceType from "./OccurrenceType";

class Occurrence extends React.Component {
    constructor(props) {
        super(props);
        this.i18n = props.i18n;
    }

    _onInput = (e) => {
        const occurrence = assign({}, this.props.occurrence);
        occurrence[e.target.name] = e.target.value;
        this.props.onChange({occurrence: occurrence});
    };

    _onChange = (change) => {
        const update = assign({}, this.props.occurrence, change);
        this.props.onChange({occurrence: update});
    };

    _onTimeChange = (type, value) => {
        if (isNaN(value)) {
            return;
        }
        const change = {};
        change[type] = new Date(Number(value)).toISOString();
        this._onChange(change);
    };

    render() {
        const occurrence = this.props.occurrence;
        return <div>
            <div className='row'>
                <div className='col-xs-4'>
                    <Input type='text' name='name' label={this.i18n('headline') + '*'}
                           title={this.i18n('occurrence.headline-tooltip')} value={occurrence.name}
                           onChange={this._onInput}/>
                </div>
            </div>

            <div className='row'>
                <div className='picker-container form-group form-group-sm col-xs-4'>
                    <label className='control-label'>{this.i18n('occurrence.start-time') + '*'}</label>
                    <DateTimePicker inputFormat='YYYY-MM-DD HH:mm:ss'
                                    dateTime={new Date(occurrence.startTime).getTime()}
                                    onChange={v => this._onTimeChange('startTime', v)} size='small'
                                    inputProps={{title: this.i18n('occurrence.start-time-tooltip')}}/>
                </div>
                <div className='picker-container form-group form-group-sm col-xs-4'>
                    <label className='control-label'>{this.i18n('occurrence.end-time') + '*'}</label>
                    <DateTimePicker inputFormat='YYYY-MM-DD HH:mm:ss' dateTime={new Date(occurrence.endTime).getTime()}
                                    onChange={v => this._onTimeChange('endTime', v)} size='small'
                                    inputProps={{title: this.i18n('occurrence.end-time-tooltip')}}/>
                </div>
            </div>
            <div className='row'>
                <div className='col-xs-4'>
                    <OccurrenceSeverity onChange={this._onInput} occurrence={occurrence}/>
                </div>
            </div>

            <div className='row'>
                <div className='col-xs-4'>
                    <OccurrenceType onChange={this._onChange} occurrence={occurrence}/>
                </div>
                <div className='col-xs-1'>
                    {this._renderOccurrenceTypeLink()}
                </div>
            </div>

            <div className='row'>
                <div className='col-xs-12'>
                    <Events occurrence={occurrence} onChange={this._onChange}/>
                </div>
            </div>
        </div>;
    }

    _renderOccurrenceTypeLink() {
        const type = this.props.occurrence.type;
        return type ? <a href={type} title={type} target='_blank' className='external-link'/> : null;
    }
}

Occurrence.propTypes = {
    occurrence: PropTypes.object.isRequired,
    onChange: PropTypes.func.isRequired
};

export default injectIntl(I18nWrapper(Occurrence));
